@@ -1,4 +1,4 @@
-# copyright 2013 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+# copyright 2013-2022 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 # contact http://www.logilab.fr -- mailto:contact@logilab.fr
 #
 # This program is free software: you can redistribute it and/or modify it under
@@ -17,7 +17,7 @@
 
 from yams.buildobjs import RelationDefinition
 
-class python_code(RelationDefinition):
-    subject = 'Executable'
-    object = 'String'
 
+class python_code(RelationDefinition):
+    subject = "Executable"
+    object = "String"
