@@ -1,4 +1,4 @@
-# copyright 2012-2013 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+# copyright 2012-2022 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 # contact http://www.logilab.fr -- mailto:contact@logilab.fr
 #
 # This program is free software: you can redistribute it and/or modify it under
@@ -16,23 +16,29 @@
 """cubicweb-processing automatic tests"""
 
 from cubicweb.devtools.testlib import AutomaticWebTest
-from cubes.processing import testing
+from cubicweb_processing import testing
 
 
 class AutomaticWebTest(AutomaticWebTest):
     """provides `to_test_etypes` and/or `list_startup_views` implementation
     to limit test scope
     """
-    no_auto_populate = set((
-            'ParameterDefinition',
-            'ParameterValueInt', 'ParameterValueFloat',
-            'ParameterValueString', 'ParameterValueFile',
-            'Wiring', 'WiringLanguage',
-                    ))
+
+    no_auto_populate = set(
+        (
+            "ParameterDefinition",
+            "ParameterValueInt",
+            "ParameterValueFloat",
+            "ParameterValueString",
+            "ParameterValueFile",
+            "Wiring",
+            "WiringLanguage",
+        )
+    )
 
     def to_test_etypes(self):
         """only test views for entities of the returned types"""
-        return set(('Executable', 'RunChain', 'Run')) | self.no_auto_populate
+        return set(("Executable", "RunChain", "Run")) | self.no_auto_populate
 
     def list_startup_views(self):
         """only test startup views of the returned identifiers"""
@@ -40,6 +46,8 @@ class AutomaticWebTest(AutomaticWebTest):
 
     post_populate = testing.generate_io
 
-if __name__ == '__main__':
+
+if __name__ == "__main__":
     from logilab.common.testlib import unittest_main
+
     unittest_main()
